==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/LogConfigFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import java.util.LinkedHashMap;
import javax.validation.Valid;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

public class LogConfigFluentImpl<A extends LogConfigFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements LogConfigFluent<A>{

    private Map<String,String> Config = new LinkedHashMap<String,String>();
    private String Type;

    public LogConfigFluentImpl(){
    }
    public LogConfigFluentImpl(LogConfig instance){
            this.withConfig(instance.getConfig()); 
            this.withType(instance.getType()); 
    }

    public A addToConfig(String key,String value){
            if(key != null && value != null) {this.Config.put(key, value);} return (A)this;
    }

    public A addToConfig(Map<String,String> map){
            if(map != null) { this.Config.putAll(map);} return (A)this;
    }

    public A removeFromConfig(String key){
            if(key != null) {this.Config.remove(key);} return (A)this;
    }

    public A removeFromConfig(Map<String,String> map){
            if(map != null) { for(Object key : map.keySet()) {this.Config.remove(key);}} return (A)this;
    }

    public Map<String,String> getConfig(){
            return this.Config;
    }

    public A withConfig(Map<String,String> Config){
            this.Config.clear();
            if (Config != null) {this.Config.putAll(Config);} return (A) this;
    }

    public String getType(){
            return this.Type;
    }

    public A withType(String Type){
            this.Type=Type; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LogConfigFluentImpl that = (LogConfigFluentImpl) o;
            if (Config != null ? !Config.equals(that.Config) :that.Config != null) return false;
            if (Type != null ? !Type.equals(that.Type) :that.Type != null) return false;
            return true;
    }




}

==> docker-model-1.3.0-sources.jar: annotations/io/fabric8/docker/api/model/LogConfigFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public class LogConfigFluentImpl<A extends LogConfigFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements LogConfigFluent<A>{

    private Map<String,String> Config = new LinkedHashMap<String,String>();
    private String Type;

    public LogConfigFluentImpl(){
    }
    public LogConfigFluentImpl(LogConfig instance){
            this.withConfig(instance.getConfig()); 
            this.withType(instance.getType()); 
    }

    public A addToConfig(String key,String value){
            if(key != null && value != null) {this.Config.put(key, value);} return (A)this;
    }

    public A addToConfig(Map<String,String> map){
            if(map != null) { this.Config.putAll(map);} return (A)this;
    }

    public A removeFromConfig(String key){
            if(key != null) {this.Config.remove(key);} return (A)this;
    }

    public A removeFromConfig(Map<String,String> map){
            if(map != null) { for(Object key : map.keySet()) {this.Config.remove(key);}} return (A)this;
    }

    public Map<String,String> getConfig(){
            return this.Config;
    }

    public A withConfig(Map<String,String> Config){
            this.Config.clear();
            if (Config != null) {this.Config.putAll(Config);} return (A) this;
    }

    public Boolean hasConfig(){
            return this.Config!=null;
    }

    public String getType(){
            return this.Type;
    }

    public A withType(String Type){
            this.Type=Type; return (A) this;
    }

    public Boolean hasType(){
            return this.Type!=null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LogConfigFluentImpl that = (LogConfigFluentImpl) o;
            if (Config != null ? !Config.equals(that.Config) :that.Config != null) return false;
            if (Type != null ? !Type.equals(that.Type) :that.Type != null) return false;
            return true;
    }




}
